
#include "U8glib.h"
#include "shape.h"
#include "triangle.h"
#include "rect.h"
#include "circle.h"
#include "cursor.h"

U8GLIB_SSD1306_128X64 u8g(U8G_I2C_OPT_DEV_0 | U8G_I2C_OPT_NO_ACK | U8G_I2C_OPT_FAST); // Fast I2C / TWI


uint8_t width = 20;
uint8_t dist = (128 / 4);
Circle   circ(dist, 64 / 2, width);
Triangle tri(dist * 2, 64 / 2, width);
Rect    rect(dist * 3, 64 / 2, width);
Cursor curs(0, 32, 4);

Shape* shapes[] = {&circ, &tri, &rect, &curs};

uint8_t draw_state = 0;
uint8_t curx = 0, cury = 0;

void draw(void) {
  u8g.setDefaultForegroundColor();
  uint8_t height = 20;
  bool invertCursor = false;
  for (int i = 0; i < 4; i++) {

    boolean b = shapes[i]->intersects(curx, cury);
    invertCursor = (invertCursor || b);
    shapes[i]->setSelected(b);
    shapes[i]->draw(u8g);
  }
  curs.setSelected(invertCursor);
  curs.draw(u8g);

}

void setup(void) {

  // flip screen, if required
  //u8g.setRot180();

#if defined(ARDUINO)
  pinMode(13, OUTPUT);
  digitalWrite(13, HIGH);
#endif
  cury = 32;
}


void loop(void) {

  // cursor position calculation
  curx ++;
  if (curx > 128) {
    curx = 0;
  }
  curs.setLocation(curx, cury);

  // picture loop
  u8g.firstPage();
  do {
    draw();
  } while ( u8g.nextPage() );

  // rebuild the picture after some delay
  delay(100);
}


